@@ -1,3 +1,17 @@
+/// Returned by `router![]` to signify if the request was handled
+pub enum RouterResult<T, U> {
+    /// Response of the request
+    Handled(T),
+    /// Request type has been returned
+    NotHandled(U),
+}
+
+impl<T, U> From<T> for RouterResult<T, U> {
+    fn from(value: T) -> Self {
+        RouterResult::Handled(value)
+    }
+}
+
 pub enum Segment {
     Glob,
     Wildcard,
@@ -70,7 +84,7 @@ where
 /// Tries to match `request` to a route in `routes`.
 /// On route match, the result of the route is returned in `Ok(_)`
 /// If no route matches, `request` is returned in `Err(_)`
-pub fn router_core<T, U>(request: T, routes: &'static [&ConstRoute<T, U>]) -> Result<U, T>
+pub fn router<T, U>(request: T, routes: &'static [&ConstRoute<T, U>]) -> RouterResult<U, T>
 where
     T: ::mimeograph_request::Request,
 {
@@ -109,8 +123,8 @@ where
             }
         }
 
-        return Ok(wrapper(request, &args));
+        return RouterResult::Handled(wrapper(request, &args));
     }
 
-    Err(request)
+    RouterResult::NotHandled(request)
 }
